@@ -22,7 +22,8 @@ import subprocess
 import sys
 import errno
 import importlib.machinery
-from .exceptions import ExecCommandFailed
+from PyInstaller.exceptions import ExecCommandFailed
+from PyInstaller._shared_with_waf import _pyi_machine
 
 # Copied from https://docs.python.org/3/library/platform.html#cross-platform.
 is_64bits = sys.maxsize > 2**32
@@ -97,7 +98,8 @@ elif is_unix:
     PYDYLIB_NAMES = {'libpython%d.%d.so.1.0' % _pyver,
                      'libpython%d.%dm.so.1.0' % _pyver,
                      'libpython%d.%dmu.so.1.0' % _pyver,
-                     'libpython%d.%dm.so' % _pyver}
+                     'libpython%d.%dm.so' % _pyver,
+                     'libpython%d.%d.so' % _pyver}
 else:
     raise SystemExit('Your platform is not yet supported. '
                      'Please define constant PYDYLIB_NAMES for your platform.')
@@ -164,6 +166,21 @@ is_conda = os.path.isdir(os.path.join(base_prefix, 'conda-meta'))
 # that the default non-conda behaviour is generally desired from PyInstaller.
 is_pure_conda = os.path.isdir(os.path.join(sys.prefix, 'conda-meta'))
 
+# Full path to python interpreter.
+python_executable = getattr(sys, '_base_executable', sys.executable)
+
+# Is this Python from Microsoft App Store (Windows only)?
+# Python from Microsoft App Store has executable pointing at empty shims.
+is_ms_app_store = is_win and os.path.getsize(python_executable) == 0
+
+if is_ms_app_store:
+    # Locate the actual executable inside base_prefix.
+    python_executable = os.path.join(
+        base_prefix, os.path.basename(python_executable))
+    if not os.path.exists(python_executable):
+        raise SystemExit('PyInstaller cannot locate real python executable '
+                         'belonging to Python from Microsoft App Store!')
+
 # In Python 3.4 module 'imp' is deprecated and there is another way how
 # to obtain magic value.
 import importlib.util
@@ -176,6 +193,8 @@ ALL_SUFFIXES = all_suffixes()
 
 
 # In Python 3 'Tkinter' has been made lowercase - 'tkinter'.
+# TODO: remove once all references are gone from both pyinstaller and
+# pyinstaller-hooks-contrib!
 modname_tkinter = 'tkinter'
 
 
@@ -201,16 +220,17 @@ if is_win:
 architecture = '64bit' if sys.maxsize > 2**32 and is_darwin else \
     '32bit' if is_darwin else platform.architecture()[0]
 
-system = platform.system()
+# Cygwin needs special handling, because platform.system() contains
+# identifiers such as MSYS_NT-10.0-19042 and CYGWIN_NT-10.0-19042 that
+# do not fit PyInstaller's OS naming scheme. Explicitly set `system` to
+# 'Cygwin'.
+if is_cygwin:
+    system = 'Cygwin'
+else:
+    system = platform.system()
 
 # Machine suffix for bootloader.
-# PyInstaller is reported to work on ARM architecture, so for that
-# case we need an extra identifying specifier on the bootloader
-# name string, like: Linux-32bit-arm, over normal Linux-32bit
-machine = 'arm' if platform.machine().startswith('arm') else \
-    'aarch' if platform.machine().startswith('aarch') else \
-    'sw_64' if platform.machine().startswith('sw_64') else None
-
+machine = _pyi_machine(platform.machine(), platform.system())
 
 # Set and get environment variables does not handle unicode strings correctly
 # on Windows.
@@ -308,8 +328,8 @@ def exec_command(*cmdargs, **kwargs):
     encoding = kwargs.pop('encoding', None)
     raise_ENOENT = kwargs.pop('__raise_ENOENT__', None)
     try:
-        out = subprocess.Popen(
-            cmdargs, stdout=subprocess.PIPE, **kwargs).communicate()[0]
+        proc = subprocess.Popen(cmdargs, stdout=subprocess.PIPE, **kwargs)
+        out = proc.communicate(timeout=60)[0]
     except OSError as e:
         if raise_ENOENT and e.errno == errno.ENOENT:
             raise
@@ -318,6 +338,9 @@ def exec_command(*cmdargs, **kwargs):
         print(e, file=sys.stderr)
         print('--' * 20, file=sys.stderr)
         raise ExecCommandFailed("Error: Executing command failed!") from e
+    except subprocess.TimeoutExpired:
+        proc.kill()
+        raise
 
     # stdout/stderr are returned as a byte array NOT as string.
     # Thus we need to convert that to proper encoding.
@@ -461,7 +484,11 @@ def exec_command_all(*cmdargs, **kwargs):
     proc = subprocess.Popen(cmdargs, bufsize=-1,  # Default OS buffer size.
             stdout=subprocess.PIPE, stderr=subprocess.PIPE, **kwargs)
     # Waits for subprocess to complete.
-    out, err = proc.communicate()
+    try:
+        out, err = proc.communicate(timeout=60)
+    except subprocess.TimeoutExpired:
+        proc.kill()
+        raise
     # stdout/stderr are returned as a byte array NOT as string.
     # Thus we need to convert that to proper encoding.
     try:
